{
	"name" : "Subscription and recurring operations",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Generic Modules/Others",
	"depends" : ["base"],
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["subscription_view.xml"],
	"active": False,
	"installable": True
}
